quietly log using t4f6.log, text replace
clear all
set memory 800m
set more off

**************************************************************************************************
* Table 4: Three-good, two-cone model: without wage equation
**************************************************************************************************

use regdata, replace

gen m = 0.5
gen n = 1.2
	sort pref_id
	by pref_id: gen HOind = 1 if logKirLir < m
	by pref_id: replace HOind = 2 if logKirLir >= m & logKirLir < n
	by pref_id: replace HOind = 3 if logKirLir >= n
	*
	* aggregation id
	*
	sort pref_id HOind
	gen pref_HOind_id = string(pref_id) + "-" + string(HOind)
	*
	* aggregation
	*
	keep pref_HOind_id HOind pref_id VAir Kr Lr wr
	collapse (mean) pref_id HOind Kr Lr wr (sum) VAir, by(pref_HOind_id)
	*
	* New id (prefecture x HO aggregation)
	*
	sort pref_id HOind
	gen temp_id = string(pref_id) + "-" + string(HOind)
	sort temp_id
	egen id = group(temp_id)
	drop temp_id
	*
	* Heckscher-Ohlin aggregate of VAL
	*
	gen VAL_HO = VAir/Lr
	gen KrLr = Kr/Lr
	*
	* intercept
	*
	gen intercept = 1
	*
	* industry dummies
	*
	tabulate HOind, generate(HOind_d)
	*
	* d
	*
		*
		* suppress constraint
		*
		keep pref_id VAL_HO KrLr wr HOind
		sort pref_id
		reshape wide VAL_HO, i(pref_id) j(HOind)
		replace VAL_HO1 = 0 if VAL_HO1 == .
		replace VAL_HO2 = 0 if VAL_HO2 == .
		replace VAL_HO3 = 0 if VAL_HO3 == .

gen i = 10
gen j = 28.64542

		gen     d1 = 0
		replace d1 = 1 if KrLr <= i
		gen     d2 = 0
		replace d2 = 1 if KrLr > i
		gen KrLr_HO1 = (KrLr - i)*d1
		gen KrLr_HO2 = KrLr*d1+(i/(i-j))*(KrLr-j)*d2
		gen KrLr_HO3 = (KrLr-i)*d2

		bootstrap, reps(1000) seed(10101) nodots: sureg (VAL_HO1 KrLr_HO1, noconstant) (VAL_HO2 KrLr_HO2, noconstant) (VAL_HO3 KrLr_HO3, noconstant), small dfk

estat ic

	set obs 48
	replace pref_id = 48 in 48
	replace KrLr = 0 in 48
	replace KrLr_HO1 = (KrLr-10) in 48
	replace KrLr_HO2 = KrLr in 48
	replace KrLr_HO3 = 0 in 48
	replace VAL_HO1 = ([#1]_b[KrLr_HO1])*(KrLr-10) in 48
	replace VAL_HO2 = 0 in 48
	replace VAL_HO3 = 0 in 48

	set obs 49
	replace pref_id = 49 in 49
	replace KrLr = 10 in 49
	replace KrLr_HO1 = (KrLr-10) in 49
	replace KrLr_HO2 = KrLr in 49
	replace KrLr_HO3 = (KrLr-10) in 49
*
* Note: If KrLr_w1 = 1 & KrLr_w2 = 0, y-axis of wages will start from zero.
*
	replace VAL_HO1 = ([#1]_b[KrLr_HO1])*(KrLr-10) in 49
	replace VAL_HO2 = ([#2]_b[KrLr_HO2])*KrLr in 49
	replace VAL_HO3 = ([#3]_b[KrLr_HO3])*(KrLr-10) in 49

	set obs 50
	replace pref_id = 50 in 50
	replace KrLr = 28.64542 in 50
	replace KrLr_HO1 = 0 in 50
	replace KrLr_HO2 = (10/(10-28.64542))*(KrLr-28.64542) in 50
	replace KrLr_HO3 = (KrLr-10) in 50
	replace VAL_HO1 = 0 in 50
	replace VAL_HO2 = ([#2]_b[KrLr_HO2])*(10/(10-28.64542))*(KrLr-28.64542) in 50
	replace VAL_HO3 = ([#3]_b[KrLr_HO3])*(KrLr-10) in 50

	predict hat1, equation(#1)
	predict hat2, equation(#2)
	predict hat3, equation(#3)

	predict stdf1, stdp equation(#1)
	predict stdf2, stdp equation(#2)
	predict stdf3, stdp equation(#3)

	drop KrLr_HO*
	reshape long VAL_HO hat stdf, i(pref_id) j(HOind)
	rename VAL_HO VAL
	estat ic

	gen lo = hat - 1.96*stdf
	gen hi = hat + 1.96*stdf

	gen HO = HOind
	rename HOind Aggregates
	label define Aggregates_label 1 "Aggregate 1" 2 "Aggregate 2" 3 "Aggregate 3"
	label values Aggregates Aggregates_label

	replace pref_id = . if pref_id >= 48

scatter VAL KrLr, by(Aggregates, note("") legend(off) yrescale) mlabposition(0) mlabel(pref_id) ms(i) || line hat KrLr, sort lcolor(black) || line lo KrLr, sort lcolor(black) lpattern(-) || line hi KrLr, sort lcolor(black) lpattern(-) ||, ytitle("Value-added per labor (Millions of Yen)") xtitle("Capital per labor ratio (Millions of Yen)") xline(10 28.64542, lstyle(grid)) xlab(10 28.6, grid)
graph save f6, replace

quietly log close
